library(ggplot2)
library(readxl)
library(plyr)
library(dplyr)
library(countrycode)
library(foreign)
library(reshape2)
library(readstata13)
library(RColorBrewer)
library(scales)
library(doBy)
library(grid)
library(gridExtra)
library(ggrepel)
library(stringr)
library(fmsb)
library(Cairo)
library(epanetReader)
library(RCurl)
library(bitops)
library(ggthemes)
library(reshape)

##### Set Directory #####
setwd("C:/Users/dwadhwa/Dropbox/Charts/3 Doing Business/output")

ds <- read.dta13("db.dta")
dt <- read.dta13("db_before.dta")

theme1 <- theme_bw() + 
  theme(plot.background = element_rect(fill ="#f3f3f3"), panel.background = element_rect(fill = "#f3f3f3")) +
  theme(panel.border= element_blank()) +
  theme(title = element_text(size = 8),
        axis.title = element_text(colour="black", size = 6)) +
  theme(legend.title = element_blank()) +
  theme(axis.line.x = element_line(colour="black", size = 1),
        axis.line.y = element_blank(),
        axis.text.x = element_text(colour="black", size = 5),
        axis.text.y = element_text(colour = "black"),
        axis.ticks.x = element_line(colour="black"),
        axis.ticks.y = element_blank()) +
  theme(legend.position = "bottom", legend.direction="vertical",
        legend.text.align = 0) +
  theme(legend.text=element_text(size=6)) +
  theme(legend.key.size = unit(0.6, "cm"))


theme2 <- theme_bw() + 
  theme(plot.background = element_rect(fill ="#f3f3f3"), panel.background = element_rect(fill = "#f3f3f3")) +
  theme(panel.border= element_blank()) +
  theme(title = element_text(size = 8),
        axis.title = element_text(colour="black", size = 6)) +
  theme(legend.title = element_blank()) +
  theme(axis.line.x = element_line(colour="black", size = 1),
        axis.line.y = element_blank(),
        axis.text.x = element_text(colour="black", size = 5),
        axis.text.y = element_text(colour = "black"),
        axis.ticks.x = element_line(colour="black"),
        axis.ticks.y = element_blank()) +
  theme(legend.position = "none")


theme3 <- theme_bw() + 
  theme(plot.background = element_rect(fill ="#f3f3f3"), panel.background = element_rect(fill = "#f3f3f3")) +
  theme(panel.border= element_blank()) +
  theme(title = element_text(size = 18),
        axis.title = element_text(colour="black", size = 12)) +
  theme(legend.title = element_blank()) +
  theme(axis.line.x = element_line(colour="black", size = 1),
        axis.line.y = element_blank(),
        axis.text.x = element_text(colour="black", size = 10),
        axis.text.y = element_text(colour = "black"),
        axis.ticks.x = element_line(colour="black"),
        axis.ticks.y = element_blank()) +
  theme(legend.position = "bottom", legend.direction="vertical",
        legend.text.align = 0) +
  theme(legend.text=element_text(size=10)) +
  theme(legend.key.size = unit(1, "cm"))

df2 <- subset(ds,Countrycode == "IND")

d <- ggplot(df2) + 
  geom_line(aes(x = year, y = rank, col = "Ranking published by Doing Business"), size = 1.5) +
  geom_line(aes(x = year, y = splicedrank, col = "Ranking using a consistent methodology and fixed sample of countries"), size = 1.5) +
  geom_point(aes(x = year, y = rank, col = "Ranking published by Doing Business"), size = 3) +
  geom_point(aes(x = year, y = splicedrank, col = "Ranking using a consistent methodology and fixed sample of countries"), size = 3) +
  geom_text(data=subset(df2, ((rank < 131 | rank > 140) & year > 2008) | year == 2006 | year == 2018),
            aes(x = year, y = rank, label=rank), size=5, position=position_dodge(width=0.9), vjust=-1.1, 
            color =  "#f95602") +
  geom_text(data=subset(df2, ((splicedrank <= 125 | splicedrank > 150) & year > 2008) | year == 2006 | year == 2018),
            aes(x = year, y = splicedrank, label=splicedrank), size=5, position=position_dodge(width=0.9), vjust=-1.1, 
            color =  "#006b77") +
  theme3 +
  labs(title = "India's 'Doing Business' rank",
       subtitle = "Changes to the World Bank methodology improved India's score",
       x="",
       y="") +
  scale_colour_manual(labels=c("Ranking published by Doing Business",
                               "Ranking using a consistent methodology and fixed sample of countries"),
                      values=c("#f95602", "#006b77")) +
  scale_x_continuous(breaks = c(2006, 2010, 2014, 2018)) +
  expand_limits(y = 95) +
  scale_y_reverse() +
  geom_segment(aes(x=2015, xend=2015, y=-Inf, yend=Inf), linetype= "dotted") +
  annotate("text", x = 2010, y = 100, label = "Indian National Congress\ngovernment") +
  annotate("text", x = 2016.5, y = 100, label = "Bharatiya Janata Party\ngovernment")

d


linechart <- function(t, t06) {
  
  ggplot(df2) + 
    geom_line(aes(x = year, y = t, col = "Ranking published by Doing Business"), size = 1) +
    geom_line(aes(x = year, y = t06, col = "Ranking using a consistent methodlody and fixed sample of countries"), size = 1) +
    geom_point(aes(x = year, y = t, col = "Ranking published by Doing Business"), size = 2) +
    geom_point(aes(x = year, y = t06, col = "Ranking using a consistent methodlody and fixed sample of countries"), size = 2) +
    theme2 +
    labs(title = t,
         subtitle = "",
         x="",
         y="") +
    scale_colour_manual(labels=c("Ranking published by Doing Business",
                                 "Ranking using a consistent methodlody and fixed sample of countries"),
                        values=c("#f95602", "#006b77")) +
    scale_x_continuous(breaks = c(2006, 2010, 2014, 2018)) +
    scale_y_continuous(breaks = c(30, 50, 70)) +
    expand_limits(y = c(17, 90))
}

p1 <- linechart(df2$Start_DTF, df2$Start_DTF06) +
  ggtitle("Starting a business") +
  geom_text(data=subset(df2, year == 2006 | year == 2018),
            aes(x = year, y = Start_DTF, label= round(Start_DTF, digit = 2)), size=2, position=position_dodge(width=0.9), vjust=-1.1, 
            color =  "#f95602") +
  geom_text(data=subset(df2, year == 2006 | year == 2018),
            aes(x = year, y = Start_DTF06, label= round(Start_DTF06, digits = 2)), size=2, position=position_dodge(width=0.9), vjust=-1.1, 
            color =  "#006b77")

p2 <- linechart(df2$Construct_DTF, df2$Construct_DTF06) +
  ggtitle("Dealing with construction permits") +
  geom_text(data=subset(df2, year == 2006 | year == 2018),
            aes(x = year, y = Construct_DTF, label= round(Construct_DTF, digit = 2)), size=2, position=position_dodge(width=0.9), vjust=-1.1, 
            color =  "#f95602") +
  geom_text(data=subset(df2, year == 2006 | year == 2018),
            aes(x = year, y = Construct_DTF06, label= round(Construct_DTF06, digits = 2)), size=2, position=position_dodge(width=0.9), vjust=-1.1, 
            color =  "#006b77")

p3 <- linechart(df2$Land_DTF, df2$Land_DTF06) +
  ggtitle("Registering property") +
  geom_text(data=subset(df2, year == 2006 | year == 2018),
            aes(x = year, y = Land_DTF, label= round(Land_DTF, digit = 2)), size=2, position=position_dodge(width=0.9), vjust=-1.1, 
            color =  "#f95602") +
  geom_text(data=subset(df2, year == 2006 | year == 2018),
            aes(x = year, y = Land_DTF06, label= round(Land_DTF06, digits = 2)), size=2, position=position_dodge(width=0.9), vjust=-1.1, 
            color =  "#006b77")

p4 <- linechart(df2$Credit_DTF, df2$Credit_DTF06) +
  ggtitle("Getting credit") +
  geom_text(data=subset(df2, year == 2006 | year == 2018),
            aes(x = year, y = Credit_DTF, label= round(Credit_DTF, digit = 2)), size=2, position=position_dodge(width=0.9), vjust=-1.1, 
            color =  "#f95602") +
  geom_text(data=subset(df2, year == 2006 | year == 2018),
            aes(x = year, y = Credit_DTF06, label= round(Credit_DTF06, digits = 2)), size=2, position=position_dodge(width=0.9), vjust=-1.1, 
            color =  "#006b77")

p5 <- linechart(df2$Invest_DTF, df2$Invest_DTF06) +
  ggtitle("Protecting minority investors") +
  geom_text(data=subset(df2, year == 2006 | year == 2018),
            aes(x = year, y = Invest_DTF, label= round(Invest_DTF, digit = 2)), size=2, position=position_dodge(width=0.9), vjust=-1.1, 
            color =  "#f95602") +
  geom_text(data=subset(df2, year == 2006 | year == 2018),
            aes(x = year, y = Invest_DTF06, label= round(Invest_DTF06, digits = 2)), size=2, position=position_dodge(width=0.9), vjust=-1.1, 
            color =  "#006b77")

p6 <- linechart(df2$Tax_DTF, df2$Tax_DTF06) +
  ggtitle("Paying taxes") +
  geom_text(data=subset(df2, year == 2006 | year == 2018),
            aes(x = year, y = Tax_DTF, label= round(Tax_DTF, digit = 2)), size=2, position=position_dodge(width=0.9), vjust=1, 
            color =  "#f95602") +
  geom_text(data=subset(df2, year == 2006 | year == 2018),
            aes(x = year, y = Tax_DTF06, label= round(Tax_DTF06, digits = 2)), size=2, position=position_dodge(width=0.9), vjust=-1.1, 
            color =  "#006b77")

p7 <- linechart(df2$Trade_DTF, df2$Trade_DTF06) +
  ggtitle("Trading across borders") +
  geom_text(data=subset(df2, year == 2006 | year == 2018),
            aes(x = year, y = Trade_DTF, label= round(Trade_DTF, digit = 2)), size=2, position=position_dodge(width=0.9), vjust=-1.1, 
            color =  "#f95602") +
  geom_text(data=subset(df2, year == 2006 | year == 2018),
            aes(x = year, y = Trade_DTF06, label= round(Trade_DTF06, digits = 2)), size=2, position=position_dodge(width=0.9), vjust=-1.1, 
            color =  "#006b77")

p8 <- linechart(df2$Contract_DTF, df2$Contract_DTF06) +
  ggtitle("Enforcing contracts") +
  geom_text(data=subset(df2, year == 2006 | year == 2018),
            aes(x = year, y = Contract_DTF, label= round(Contract_DTF, digit = 2)), size=2, position=position_dodge(width=0.9), vjust=-1.1, 
            color =  "#f95602") +
  geom_text(data=subset(df2, year == 2006 | year == 2018),
            aes(x = year, y = Contract_DTF06, label= round(Contract_DTF06, digits = 2)), size=2, position=position_dodge(width=0.9), vjust=-1.1, 
            color =  "#006b77")

p9 <- linechart(df2$Bankrupt_DTF, df2$Bankrupt_DTF06) +
  ggtitle("Resolving insolvency") +
  geom_text(data=subset(df2, year == 2006 | year == 2018),
            aes(x = year, y = Bankrupt_DTF, label= round(Bankrupt_DTF, digit = 2)), size=2, position=position_dodge(width=0.9), vjust=-1.1, 
            color =  "#f95602") +
  geom_text(data=subset(df2, year == 2006 | year == 2018),
            aes(x = year, y = Bankrupt_DTF06, label= round(Bankrupt_DTF06, digits = 2)), size=2, position=position_dodge(width=0.9), vjust=-1.1, 
            color =  "#006b77")

p10 <- ggplot(df2) + 
  geom_line(aes(x = year, y = DTF_total, col = "Distance to frontier published by Doing Business"), size = 1) +
  geom_line(aes(x = year, y = DTF06_total, col = "Distance to frontier using a consistent methodology and fixed sample of countries"), size = 1) +
  geom_point(aes(x = year, y = DTF_total, col = "Distance to frontier published by Doing Business"), size = 2) +
  geom_point(aes(x = year, y = DTF06_total, col = "Distance to frontier using a consistent methodology and fixed sample of countries"), size = 2) +
  theme1 +
  labs(subtitle = "",
       x="",
       y="") +
  scale_colour_manual(labels=c("Distance to frontier published by Doing Business",
                               "Distance to frontier using a consistent methodology and fixed sample of countries"),
                      values=c("#f95602", "#006b77")) +
  scale_x_continuous(breaks = c(2006, 2010, 2014, 2018)) +
  expand_limits(y = c(17, 85)) +
  ggtitle("Total (distance to frontier)") +
  geom_text(data=subset(df2, year == 2006 | year == 2018),
            aes(x = year, y = DTF_total, label= round(DTF_total, digit = 2)), size=2, position=position_dodge(width=0.9), vjust=-1.1, 
            color =  "#f95602") +
  geom_text(data=subset(df2, year == 2006 | year == 2018),
            aes(x = year, y = DTF06_total, label= round(DTF06_total, digits = 2)), size=2, position=position_dodge(width=0.9), vjust=-1.1, 
            color =  "#006b77")
p10

dt <- subset(dt,Countrycode == "IND")

p11 <- ggplot(dt) + 
  geom_line(aes(x = year, y = Power_DTF, col = "Distance to frontier published by Doing Business"), size = 1) +
  geom_point(aes(x = year, y = Power_DTF, col = "Distance to frontier published by Doing Business"), size = 2) +
  geom_text(data=subset(dt, year == 2010 | year == 2018),
            aes(x = year, y = Power_DTF, label= round(Power_DTF, digit = 2)), size=2, position=position_dodge(width=0.9), vjust=-1.1, 
            color =  "#f95602") +
  theme2 +
  labs(title = "Getting electricity",
       subtitle = "",
       x="",
       y="") +
  scale_colour_manual(labels=c("Distance to frontier published by Doing Business",
                               "Distance to frontier using a consistent methodology and fixed sample of countries"),
                      values=c("#f95602", "#006b77")) +
  scale_x_continuous(breaks = c(2006, 2010, 2014, 2018)) +
  scale_y_continuous(breaks = c(30, 50, 70)) +
  expand_limits(y = c(17, 87))
p11


vplayout <- function(x, y) viewport(layout.pos.row = x, layout.pos.col = y)

grid.newpage()
pushViewport(viewport(layout = grid.layout(6, 2))) # 6 rows, 2 columns
print(p1,  vp = vplayout(1,   1))  
print(p2,  vp = vplayout(2,   1))
print(p3,  vp = vplayout(3,   1))
print(p4,  vp = vplayout(4,   1))
print(p5,  vp = vplayout(5,   1))
print(p6,  vp = vplayout(6,   1))
print(p7,  vp = vplayout(1,   2))
print(p8,  vp = vplayout(2,   2))
print(p9,  vp = vplayout(3,   2))
print(p11, vp = vplayout(4,   2))
print(p10, vp = vplayout(5:6, 2))
